@@ -29,7 +29,7 @@ public:
     uint_least32_t frequency;
     int            precision;
     int            channels;
-    uint_least32_t bufSize;       // sample buffer size
+    uint_least32_t bufSize;       // sample buffer size measured in frames
 
     AudioConfig() :
         frequency(48000),
@@ -37,7 +37,7 @@ public:
         channels(1),
         bufSize(0) {}
 
-    uint_least32_t bytesPerMillis() const { return (precision/8 * channels * frequency) / 1000; }
+    uint_least32_t getBufBytes() const { return bufSize * channels * (precision/8); }
 };
 
 #endif  // AUDIOCONFIG_H
