@@ -52,12 +52,12 @@ void Audio_OSS::outOfOrder ()
 {
     // Reset everything.
     clearError();
-    _audiofd = -1;
+    m_audiofd = -1;
 }
 
 bool Audio_OSS::open (AudioConfig &cfg)
 {
-    if (_audiofd != -1)
+    if (m_audiofd != -1)
     {
         setError("Device already in use");
         return false;
@@ -70,19 +70,19 @@ bool Audio_OSS::open (AudioConfig &cfg)
             throw error("Could not locate an audio device.");
         }
 
-        if ((_audiofd = ::open (AUDIODEVICE, O_WRONLY, 0)) == (-1))
+        if ((m_audiofd = ::open (AUDIODEVICE, O_WRONLY, 0)) == (-1))
         {
             throw error("Could not open audio device.");
         }
 
         int format = AFMT_S16_LE;
-        if (ioctl (_audiofd, SNDCTL_DSP_SETFMT, &format) == (-1))
+        if (ioctl (m_audiofd, SNDCTL_DSP_SETFMT, &format) == (-1))
         {
             throw error("Could not set sample format.");
         }
 
         // Set mono/stereo.
-        if (ioctl (_audiofd, SNDCTL_DSP_CHANNELS, &cfg.channels) == (-1))
+        if (ioctl (m_audiofd, SNDCTL_DSP_CHANNELS, &cfg.channels) == (-1))
         {
             throw error("Could not set mono/stereo.");
         }
@@ -99,13 +99,13 @@ bool Audio_OSS::open (AudioConfig &cfg)
         }
 
         // Set frequency.
-        if (ioctl (_audiofd, SNDCTL_DSP_SPEED, &cfg.frequency) == (-1))
+        if (ioctl (m_audiofd, SNDCTL_DSP_SPEED, &cfg.frequency) == (-1))
         {
             throw error("Could not set frequency.");
         }
 
         int temp = 0;
-        ioctl (_audiofd, SNDCTL_DSP_GETBLKSIZE, &temp);
+        ioctl (m_audiofd, SNDCTL_DSP_GETBLKSIZE, &temp);
         cfg.bufSize = (uint_least32_t) temp;
 
         try
@@ -128,10 +128,10 @@ bool Audio_OSS::open (AudioConfig &cfg)
     {
         setError(e.message());
 
-        if (_audiofd != -1)
+        if (m_audiofd != -1)
         {
             close ();
-            _audiofd = -1;
+            m_audiofd = -1;
         }
 
         return false;
@@ -142,9 +142,9 @@ bool Audio_OSS::open (AudioConfig &cfg)
 // reset any variables that reflect the current state.
 void Audio_OSS::close ()
 {
-    if (_audiofd != -1)
+    if (m_audiofd != -1)
     {
-        ::close (_audiofd);
+        ::close (m_audiofd);
         delete [] _sampleBuffer;
         outOfOrder ();
     }
@@ -152,22 +152,22 @@ void Audio_OSS::close ()
 
 void Audio_OSS::reset ()
 {
-    if (_audiofd != -1)
+    if (m_audiofd != -1)
     {
-        ioctl (_audiofd, SNDCTL_DSP_RESET, 0);
+        ioctl (m_audiofd, SNDCTL_DSP_RESET, 0);
     }
 }
 
 bool Audio_OSS::write (uint_least32_t frames)
 {
-    if (_audiofd == -1)
+    if (m_audiofd == -1)
     {
         setError("Device not open.");
         return false;
     }
 
     size_t const bytes = static_cast<size_t>(frames) * m_frameSize;
-    ssize_t res = ::write (_audiofd, _sampleBuffer, bytes);
+    ssize_t res = ::write (m_audiofd, _sampleBuffer, bytes);
     if (res < 0)
     {
         setError(strerror(errno));
